@@ -1730,8 +1730,8 @@ class ThrottlingStorageClientFactory(StorageClientFactory, object):
         """
         delayed_call = getattr(self, call_id)
         # check if we already have a DelayedCall running
-        if delayed_call is None or (not delayed_call.active() \
-           and delayed_call.cancelled):
+        if delayed_call is None or (not delayed_call.active()
+                                    and delayed_call.cancelled):
             return self.callLater(period, func)
         return delayed_call
 
