@@ -31,6 +31,12 @@ import re
 from uuid import UUID
 from google.protobuf.message import Message as _PBMessage
 from google.protobuf.internal.containers import BaseContainer as _PBContainer
+try:
+    from google.protobuf.internal.cpp_message import RepeatedCompositeContainer
+except ImportError:
+    CONTAINER_CLASSES = _PBContainer
+else:
+    CONTAINER_CLASSES = (_PBContainer, RepeatedCompositeContainer)
 
 
 def is_valid_node(node_id):
@@ -90,7 +96,7 @@ def validate_message(message):
     is_invalid = []
     from ubuntuone.storageprotocol import validators  # this is us!
     for descriptor, submsg in message.ListFields():
-        if isinstance(submsg, _PBContainer):
+        if isinstance(submsg, CONTAINER_CLASSES):
             # containers are iterables that have messages in them
             for i in submsg:
                 is_invalid.extend(validate_message(i))
